Struct aws_sdk_networkmanager::client::fluent_builders::CreateLink [−][src]
pub struct CreateLink<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to CreateLink.
Creates a new link for a specified site.
Implementations
impl<C, M, R> CreateLink<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> CreateLink<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(self) -> Result<CreateLinkOutput, SdkError<CreateLinkError>> where
R::Policy: SmithyRetryPolicy<CreateLinkInputOperationOutputAlias, CreateLinkOutput, CreateLinkError, CreateLinkInputOperationRetryAlias>,
pub async fn send(self) -> Result<CreateLinkOutput, SdkError<CreateLinkError>> where
R::Policy: SmithyRetryPolicy<CreateLinkInputOperationOutputAlias, CreateLinkOutput, CreateLinkError, CreateLinkInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The ID of the global network.
The ID of the global network.
A description of the link.
Length Constraints: Maximum length of 256 characters.
A description of the link.
Length Constraints: Maximum length of 256 characters.
The type of the link.
Constraints: Cannot include the following characters: | \ ^
Length Constraints: Maximum length of 128 characters.
The type of the link.
Constraints: Cannot include the following characters: | \ ^
Length Constraints: Maximum length of 128 characters.
The upload speed and download speed in Mbps.
The provider of the link.
Constraints: Cannot include the following characters: | \ ^
Length Constraints: Maximum length of 128 characters.
The provider of the link.
Constraints: Cannot include the following characters: | \ ^
Length Constraints: Maximum length of 128 characters.
The ID of the site.
Appends an item to Tags.
To override the contents of this collection use set_tags.
The tags to apply to the resource during creation.
The tags to apply to the resource during creation.